@@ -1,4 +1,4 @@
-// Copyright 2019 The Hugo Authors. All rights reserved.
+// Copyright 2020 The Hugo Authors. All rights reserved.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -18,7 +18,8 @@ import (
 	"io"
 	"sync/atomic"
 
-	"github.com/gohugoio/hugo/config"
+	"github.com/gohugoio/hugo/resources"
+
 	"github.com/gohugoio/hugo/media"
 
 	"github.com/gohugoio/hugo/minifiers"
@@ -68,17 +69,21 @@ type Descriptor struct {
 // DestinationPublisher is the default and currently only publisher in Hugo. This
 // publisher prepares and publishes an item to the defined destination, e.g. /public.
 type DestinationPublisher struct {
-	fs  afero.Fs
-	min minifiers.Client
+	fs                    afero.Fs
+	min                   minifiers.Client
+	htmlElementsCollector *htmlElementsCollector
 }
 
 // NewDestinationPublisher creates a new DestinationPublisher.
-func NewDestinationPublisher(fs afero.Fs, outputFormats output.Formats, mediaTypes media.Types, cfg config.Provider) (pub DestinationPublisher, err error) {
-	pub = DestinationPublisher{fs: fs}
-	pub.min, err = minifiers.New(mediaTypes, outputFormats, cfg)
-	if err != nil {
-		return
+func NewDestinationPublisher(rs *resources.Spec, outputFormats output.Formats, mediaTypes media.Types) (pub DestinationPublisher, err error) {
+	fs := rs.BaseFs.PublishFs
+	cfg := rs.Cfg
+	var classCollector *htmlElementsCollector
+	if rs.BuildConfig.WriteStats {
+		classCollector = newHTMLElementsCollector()
 	}
+	pub = DestinationPublisher{fs: fs, htmlElementsCollector: classCollector}
+	pub.min, err = minifiers.New(mediaTypes, outputFormats, cfg)
 	return
 }
 
@@ -111,16 +116,38 @@ func (p DestinationPublisher) Publish(d Descriptor) error {
 	}
 	defer f.Close()
 
-	_, err = io.Copy(f, src)
+	var w io.Writer = f
+
+	if p.htmlElementsCollector != nil && d.OutputFormat.IsHTML {
+		w = io.MultiWriter(w, newHTMLElementsCollectorWriter(p.htmlElementsCollector))
+	}
+
+	_, err = io.Copy(w, src)
 	if err == nil && d.StatCounter != nil {
 		atomic.AddUint64(d.StatCounter, uint64(1))
 	}
+
 	return err
 }
 
+func (p DestinationPublisher) PublishStats() PublishStats {
+	if p.htmlElementsCollector == nil {
+		return PublishStats{}
+	}
+
+	return PublishStats{
+		HTMLElements: p.htmlElementsCollector.getHTMLElements(),
+	}
+}
+
+type PublishStats struct {
+	HTMLElements HTMLElements `json:"htmlElements"`
+}
+
 // Publisher publishes a result file.
 type Publisher interface {
 	Publish(d Descriptor) error
+	PublishStats() PublishStats
 }
 
 // XML transformer := transform.New(urlreplacers.NewAbsURLInXMLTransformer(path))
